@@ -308,3 +308,17 @@ class GPD3303S(object):
             return ret[:-len(self.eol)]
         else:
             raise exceptions.RuntimeError('Cannot read error message')
+
+
+class GPD4303S(GPD3303S):
+    def isValidChannel(self, channel):
+        """
+        Check if the given channel number is valid or not. Only channels 1 to 4
+        are allowed.
+        """
+
+        if not (1 <= channel <= 4):
+            raise exceptions.RuntimeError('Invalid channel number: %d was given.' % channel)
+        return True
+
+
